.. _refman_ext_benchmark:

BenchMark
=========

This section contains source code documentation of Benchmark extension.

.. _refman_ext_benchmark_benchmark:

benchmark
^^^^^^^^^

.. automodule:: hydratk.extensions.benchmark.benchmark
   :member-order: bysource

.. _refman_ext_benchmark_tests_disk:

disk
^^^^

.. automodule:: hydratk.extensions.benchmark.tests.disk
   :member-order: bysource
   
.. _refman_ext_benchmark_tests_event:

event
^^^^^

.. automodule:: hydratk.extensions.benchmark.tests.event
   :member-order: bysource
   
.. _refman_ext_benchmark_tests_math:

math
^^^^

.. automodule:: hydratk.extensions.benchmark.tests.math
   :member-order: bysource
   
.. _refman_ext_benchmark_tests_memory:

memory
^^^^^^

.. automodule:: hydratk.extensions.benchmark.tests.memory
   :member-order: bysource
   
.. _refman_ext_benchmark_tests_network:

network
^^^^^^^

.. automodule:: hydratk.extensions.benchmark.tests.network
   :member-order: bysource            